import { ViewController } from '../nav/view-controller';
/**
 * @name Toast
 * @description
 * An Toast is a small message that appears in the lower part of the screen.
 * It's useful for displaying success messages, error messages, etc.
 *
 * @usage
 * ```ts
 * constructor(nav: NavController) {
 *   this.nav = nav;
 * }
 *
 * presentToast() {
 *   let toast = Toast.create({
 *     message: 'User was added successfully',
 *     duration: 3000
 *   });
 *   this.nav.present(toast);
 * }
 * ```
 *
 * @demo /docs/v2/demos/toast/
 */
export declare class Toast extends ViewController {
    constructor(opts?: ToastOptions);
    /**
    * @private
    */
    getTransitionName(direction: string): any;
    /**
     * @param {string} message  Toast message content
     */
    setMessage(message: string): void;
    /**
     *
     *  Toast options
     *
     *  | Property              | Type      | Description                                                                   |
     *  |-----------------------|-----------|---------------------------------------------------------------------------    |
     *  | message               | `string`  | The message for the toast. Long strings will wrap and the toast container will expand. **(required)**                                                     |
     *  | duration              | `number`  | The amount of time in milliseconds the toast should appear *(optional)*         |
     *  | cssClass              | `string`  | Any additional class for the toast *(optional)*                                 |
     *  | showCloseButton       | `boolean` | Whether or not to show an optional button to close the toast. *(optional)*      |
     *  | closeButtonText       | `string`  | Text to display in the close button. *(optional)*                               |
     *  | enableBackdropDismiss | `boolean` | Whether the the toast should be dismissed by tapping the backdrop *(optional)*  |
     *
     * @param {object} ToastOptions Toast. See the above table for available options.
     */
    static create(opts?: ToastOptions): Toast;
}
export interface ToastOptions {
    title?: string;
    cssClass?: string;
    buttons?: Array<any>;
    duration?: number;
    showCloseButton?: boolean;
    closeButtonText?: string;
    enableBackdropDismiss?: boolean;
}
